@@ -3,12 +3,14 @@ from typing import Any
 
 from .base import Downloader
 
-GEOCONFIRMED_ENDPOINT = 'https://geoconfirmed.azurewebsites.net/api/map/GetMap/Ukraine'  # noqa
+GEOCONFIRMED_ENDPOINT = 'https://geoconfirmed.azurewebsites.net/api/placemark/Ukraine'  # noqa
+# Also available:
+# https://geoconfirmed.azurewebsites.net/api/placemark/Ukraine
 
 class GeoConfirmedDownloader(Downloader):
     """
     @GeoConfirmed
-    Data from https://geoconfirmed.azurewebsites.net/api/map/GetMap/Ukraine
+    Data from https://geoconfirmed.azurewebsites.net/api/placemark/Ukraine
     with blessing from author
     """
 
